==> components-1.2.0.tgz: package/esm/Atoms/Tabs/TabMenuToggler.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _templateObject() {
  var data = _taggedTemplateLiteral(["\n  position: absolute;\n  top: 10px;\n  right: 20px;\n\n  @media (min-width: 48rem) {\n    display: none;\n  }\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}

function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import Icon from '../../Atoms/Icons/Icon';
var Toggler = styled(Icon).attrs({
  name: 'hamburgerMenu',
  selectable: true,
  size: '1.3rem'
})(_templateObject());

var TabMenuToggler = function TabMenuToggler(_ref) {
  var onToggle = _ref.onToggle,
      rest = _objectWithoutProperties(_ref, ["onToggle"]);

  return React.createElement(Toggler, _extends({
    onClick: onToggle
  }, rest));
};

TabMenuToggler.propTypes = {
  children: PropTypes.node,
  onToggle: PropTypes.func
};
export default TabMenuToggler;

==> components-2.0.0.tgz: package/esm/Atoms/Tabs/TabMenuToggler.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _templateObject() {
  var data = _taggedTemplateLiteral(["\n  position: absolute;\n  top: 10px;\n  right: 20px;\n\n  @media (min-width: 48rem) {\n    display: none;\n  }\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}

function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import { FaIcon } from '../../Atoms/Icons';
var Toggler = styled(FaIcon.Bars).attrs({
  selectable: true,
  size: '1.3rem'
})(_templateObject());

var TabMenuToggler = function TabMenuToggler(_ref) {
  var onToggle = _ref.onToggle,
      rest = _objectWithoutProperties(_ref, ["onToggle"]);

  return React.createElement(Toggler, _extends({
    onClick: onToggle
  }, rest));
};

TabMenuToggler.propTypes = {
  children: PropTypes.node,
  onToggle: PropTypes.func
};
export default TabMenuToggler;
